Summary:	Enhanced system logging and kernel message trapping daemons
Name:		rsyslog
Version:	2.0.1
Release:	%mkrel 2
License:	GPL
Group:		System/Kernel and hardware
URL:		http://www.rsyslog.com/
Source0:	http://download.rsyslog.com/%{name}/%{name}-%{version}.tar.gz
Source1:	rsyslog.init
Source2:	rsyslog.sysconfig
Source3:	rsyslog.conf
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	krb5-devel
BuildRequires:	mysql-devel >= 4.0
BuildRequires:	postgresql-devel
BuildRequires:	zlib-devel
Requires:	logrotate
Provides:       syslog-daemon
Requires(post):	rpm-helper
Requires(preun):rpm-helper
#Provides:	sysklogd = 1.4.3-1
#Obsoletes:	sysklogd < 1.4.3-1
Conflicts:	logrotate < 3.5.2
Buildroot:	%{_tmppath}/%{name}-%{version}-%{release}-root

%description
Rsyslog is an enhanced multi-threaded syslogd supporting, among others, MySQL,
PostgreSQL, syslog/tcp, RFC 3195, permitted sender lists, filtering on any
message part, and fine grain output format control. It is quite compatible to
stock sysklogd and can be used as a drop-in replacement. Its advanced features
make it suitable for enterprise-class, encryption protected syslog relay chains
while  at the same time being very easy to setup for the novice user.

%package	mysql
Summary:	MySQL support for rsyslog
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}-%{release}

%description	mysql
The rsyslog-mysql package contains a dynamic shared object that will add
MySQL database support to rsyslog.

%package	pgsql
Summary:	PostgreSQL support for rsyslog
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}-%{release}

%description	pgsql
The rsyslog-pgsql package contains a dynamic shared object that will add
PostgreSQL database support to rsyslog.

%package	gssapi
Summary:	GSS-API support for rsyslog
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}-%{release}

%description	gssapi
The rsyslog-gssapi package contains a dynamic shared object that will add
GSS-API support to rsyslog.

%package	docs
Summary:	HTML documentation for rsyslog
Group:		System/Kernel and hardware

%description	docs
This package contains the HTML documentation for rsyslog.

%prep

%setup -q

%build
%serverbuild

%configure2_5x \
    --disable-static \
    --sbindir=/sbin \
    --enable-largefile \
    --enable-regexp \
    --enable-zlib \
    --enable-gssapi-krb5 \
    --enable-pthreads \
    --enable-klogd \
    --enable-inet \
    --enable-mysql \
    --enable-pgsql

%make

%install
rm -rf %{buildroot}

%makeinstall_std

install -d -m 755 %{buildroot}%{_initrddir}
install -d -m 755 %{buildroot}%{_sysconfdir}/sysconfig
install -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
install -d -m 755 %{buildroot}%{_sysconfdir}/rsyslog.d

install -p -m 755 %{SOURCE1} %{buildroot}%{_initrddir}/rsyslog
install -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/rsyslog.conf
install -p -m 644 redhat/rsyslog.log %{buildroot}%{_sysconfdir}/logrotate.d/rsyslog
install -p -m 644 %{SOURCE2} %{buildroot}/%{_sysconfdir}/sysconfig/rsyslog

#get rid of *.la
rm %{buildroot}/%{_libdir}/rsyslog/*.la

# fix html docs
rm -rf html_docs; mkdir -p html_docs
cp doc/* html_docs/
chmod 644 html_docs/*
rm -f html_docs/Makefile*

%post
%_post_service rsyslog

for n in /var/log/{messages,secure,maillog,spooler}; do
    [ -f $n ] && continue
    umask 066 && touch $n
done

if [ "$1" = 0 ]; then
    # use sysklogd configuration file
    if [ -f /etc/sysconfig/syslog ]; then
        mv -f /etc/sysconfig/rsyslog /etc/sysconfig/rsyslog.rpmnew
        cp /etc/sysconfig/syslog /etc/sysconfig/rsyslog
    fi
fi

%triggerpostun -- rsyslog < 2.0.1-2mdv2008.1
if [ ! -f /etc/syslog.conf ]; then
    # restore syslog.conf
    mv -f /etc/rsyslog.conf /etc/syslog.conf
    mv -f /etc/rsyslog.conf.rpmnew /etc/rsyslog.conf
fi

%preun
%_preun_service rsyslog

%postun
if [ "$1" -ge "1" ]; then
    %{_initrddir}/rsyslog condrestart > /dev/null 2>&1 ||:
fi	

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING INSTALL NEWS README
%config(noreplace) %{_sysconfdir}/rsyslog.conf
%config(noreplace) %{_sysconfdir}/sysconfig/rsyslog
%config(noreplace) %{_sysconfdir}/logrotate.d/rsyslog
%dir %{_sysconfdir}/rsyslog.d
%{_initrddir}/rsyslog
/sbin/rsyslogd
/sbin/rklogd
/sbin/rfc3195d
%{_mandir}/*/*

%files mysql
%defattr(-,root,root)
%doc plugins/ommysql/createDB.sql plugins/ommysql/contrib/delete_mysql
%{_libdir}/rsyslog/ommysql.so

%files pgsql
%defattr(-,root,root)
%doc plugins/ompgsql/createDB.sql
%{_libdir}/rsyslog/ompgsql.so

%files gssapi
%defattr(-,root,root)
%{_libdir}/rsyslog/omgssapi.so

%files docs
%defattr(-,root,root)
%doc html_docs/*


%changelog
* Mon Jan 28 2008 Olivier Blin <oblin@mandriva.com> 2.0.1-2mdv2008.1
+ Revision: 159377
- create /etc/rsyslog.d and include /etc/rsyslog.d/*.conf from rsyslog.conf
- restore syslog.conf on upgrade of previous rsyslog package
- include syslog.conf in rsyslog.conf instead of moving the file, to ease cohabitation of sysklogd and rsyslog packages
- do not remove original /etc/sysconfig/syslog
- migrate sysklogd configuration files in initial installation only

* Thu Jan 24 2008 Oden Eriksson <oeriksson@mandriva.com> 2.0.1-1mdv2008.1
+ Revision: 157600
- 2.0.1 (3.x.x is the unstable branch)

  + Olivier Blin <oblin@mandriva.com>
    - 3.10.2

* Wed Jan 02 2008 Oden Eriksson <oeriksson@mandriva.com> 2.0.0-1mdv2008.1
+ Revision: 140614
- 2.0.0

* Sat Dec 29 2007 Oden Eriksson <oeriksson@mandriva.com> 1.21.2-1mdv2008.1
+ Revision: 139317
- 1.21.2

* Mon Dec 24 2007 Oden Eriksson <oeriksson@mandriva.com> 1.21.1-1mdv2008.1
+ Revision: 137430
- 1.21.1

* Wed Dec 19 2007 Oden Eriksson <oeriksson@mandriva.com> 1.21.0-1mdv2008.1
+ Revision: 134359
- 1.21.0
- enable all features

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Dec 13 2007 Oden Eriksson <oeriksson@mandriva.com> 1.20.1-1mdv2008.1
+ Revision: 119281
- 1.20.1

* Fri Dec 07 2007 Oden Eriksson <oeriksson@mandriva.com> 1.20.0-1mdv2008.1
+ Revision: 116322
- 1.20.0

* Mon Dec 03 2007 Oden Eriksson <oeriksson@mandriva.com> 1.19.12-1mdv2008.1
+ Revision: 114551
- 1.19.12

* Thu Nov 22 2007 Oden Eriksson <oeriksson@mandriva.com> 1.19.10-1mdv2008.1
+ Revision: 111227
- import rsyslog


* Thu Nov 22 2007 Oden Eriksson <oeriksson@mandriva.com> 1.19.10-1mdv2008.1
- initial Mandriva package (fedora import)

* Wed Oct 03 2007 Peter Vrabec <pvrabec@redhat.com> 1.19.6-3
- remove NUL character from recieved messages

* Tue Sep 25 2007 Tomas Heinrich <theinric@redhat.com> 1.19.6-2
- fix message suppression (303341)

* Tue Sep 25 2007 Tomas Heinrich <theinric@redhat.com> 1.19.6-1
- upstream bugfix release

* Tue Aug 28 2007 Peter Vrabec <pvrabec@redhat.com> 1.19.2-1
- upstream bugfix release
- support for negative app selector, patch from 
  theinric@redhat.com

* Fri Aug 17 2007 Peter Vrabec <pvrabec@redhat.com> 1.19.0-1
- new upstream release with MySQL support(as plugin)

* Wed Aug 08 2007 Peter Vrabec <pvrabec@redhat.com> 1.18.1-1
- upstream bugfix release

* Mon Aug 06 2007 Peter Vrabec <pvrabec@redhat.com> 1.18.0-1
- new upstream release

* Thu Aug 02 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.6-1
- upstream bugfix release

* Mon Jul 30 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.5-1
- upstream bugfix release
- fix typo in provides 

* Wed Jul 25 2007 Jeremy Katz <katzj@redhat.com> - 1.17.2-4
- rebuild for toolchain bug

* Tue Jul 24 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.2-3
- take care of sysklogd configuration files in %%post

* Tue Jul 24 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.2-2
- use EVR in provides/obsoletes sysklogd

* Mon Jul 23 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.2-1
- upstream bug fix release

* Fri Jul 20 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.1-1
- upstream bug fix release
- include html docs (#248712)
- make "-r" option compatible with sysklogd config (248982)

* Tue Jul 17 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.0-1
- feature rich upstream release

* Thu Jul 12 2007 Peter Vrabec <pvrabec@redhat.com> 1.15.1-2
- use obsoletes and hadle old config files

* Wed Jul 11 2007 Peter Vrabec <pvrabec@redhat.com> 1.15.1-1
- new upstream bugfix release

* Tue Jul 10 2007 Peter Vrabec <pvrabec@redhat.com> 1.15.0-1
- new upstream release introduce capability to generate output 
  file names based on templates

* Tue Jul 03 2007 Peter Vrabec <pvrabec@redhat.com> 1.14.2-1
- new upstream bugfix release

* Mon Jul 02 2007 Peter Vrabec <pvrabec@redhat.com> 1.14.1-1
- new upstream release with IPv6 support

* Tue Jun 26 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.5-3
- add BuildRequires for  zlib compression feature

* Mon Jun 25 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.5-2
- some spec file adjustments.
- fix syslog init script error codes (#245330)

* Fri Jun 22 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.5-1
- new upstream release

* Fri Jun 22 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.4-2
- some spec file adjustments.

* Mon Jun 18 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.4-1
- upgrade to new upstream release

* Wed Jun 13 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.2-2
- DB support off

* Tue Jun 12 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.2-1
- new upstream release based on redhat patch

* Fri Jun 08 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.1-2
- rsyslog package provides its own kernel log. daemon (rklogd)

* Mon Jun 04 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.1-1
- Initial rpm build
